@@ -23,7 +23,7 @@
 
 use std::env;
 use std::ffi::{OsStr, OsString};
-use std::io::{self, ErrorKind, Write};
+use std::io::{self, ErrorKind, IsTerminal, Write};
 use std::path::{Component, PathBuf};
 use std::process::exit;
 
@@ -35,7 +35,7 @@ use crate::fs::feature::git::GitCache;
 use crate::fs::filter::GitIgnore;
 use crate::fs::{Dir, File};
 use crate::options::{vars, Options, OptionsResult, Vars};
-use crate::output::{details, escape, grid, grid_details, lines, Mode, View};
+use crate::output::{details, escape, file_name, grid, grid_details, lines, Mode, View};
 use crate::theme::Theme;
 
 mod fs;
@@ -58,6 +58,8 @@ fn main() {
         warn!("Failed to enable ANSI support: {}", e);
     }
 
+    let stdout_istty = io::stdout().is_terminal();
+
     let args: Vec<_> = env::args_os().skip(1).collect();
     match Options::parse(args.iter().map(std::convert::AsRef::as_ref), &LiveVars) {
         OptionsResult::Ok(options, mut input_paths) => {
@@ -71,9 +73,7 @@ fn main() {
             let writer = io::stdout();
 
             let console_width = options.view.width.actual_terminal_width();
-            let theme = options
-                .theme
-                .to_theme(terminal_size::terminal_size().is_some());
+            let theme = options.theme.to_theme(stdout_istty);
             let exa = Exa {
                 options,
                 writer,
@@ -231,6 +231,10 @@ impl<'args> Exa<'args> {
         is_only_dir: bool,
         exit_status: i32,
     ) -> io::Result<i32> {
+        let View {
+            file_style: file_name::Options { quote_style, .. },
+            ..
+        } = self.options.view;
         for dir in dir_files {
             // Put a gap between directories, or between the list of files and
             // the first directory.
@@ -247,6 +251,7 @@ impl<'args> Exa<'args> {
                     &mut bits,
                     Style::default(),
                     Style::default(),
+                    quote_style,
                 );
                 writeln!(&mut self.writer, "{}:", ANSIStrings(&bits))?;
             }
